@@ -87,7 +87,7 @@ our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 
 our @EXPORT = ( @{ $EXPORT_TAGS{'classes'} } );
 
-our $VERSION = '1.00';
+our $VERSION = '1.01';
 
 #--------------------------------------------------------------
 #	ALL THAI UNICODE CHARACTERS IN THIS MODULE
@@ -193,6 +193,8 @@ sub IsThaiMCons { #THAI MID-CLASS CONSONANTS
 
 sub IsThaiLCons { #THAI LOW-CLASS CONSONANTS
 # ค ฅ ฆ ง ช ซ ฌ ญ ฑ ฒ ณ ท ธ น พ ฟ ภ ม ย ร ฤ ล ฦ ว ฬ ฮ 
+#NOTE: The included ฤ and ฦ are usually classed as vowels, but
+#when they function as consonants they would be in this class.
     return join "\n",
  '0E04', '0E05', '0E06', '0E07', '0E0A', '0E0B', '0E0C', '0E0D', 
  '0E11', '0E12', '0E13', '0E17', '0E18', '0E19', '0E1E', '0E1F', 
@@ -217,26 +219,29 @@ sub IsThaiFinCons { #THAI SYLLABLE-ENDING CONSONANTS (FINAL)
 sub IsThaiDualCons {
 # BECAUSE EACH \p{...} CHARACTER DEFINED CAN BE ONLY A SINGLE
 # CHARACTER, AND NOT A CHARACTER CLUSTER, THIS CHAR CLASS, AND
-# THE TWO WHICH FOLLOW, ARE CONSIDERED EXPERIMENTAL AND OF 
+# THE TWO WHICH FOLLOW IT, ARE CONSIDERED EXPERIMENTAL AND OF 
 # LIMITED USEFULNESS.
 #
 # NON-EXHAUSTIVE LIST OF EXAMPLES (INITIAL CONSONANT CLUSTERS)
-# กล คว คล จร ปล พร ตร ทร สร
-# ห + sonorant (หญ หม หล หร หน หง) 
-# อ + sonorant (อย)
+# กว กล กร ขร ขล ขว คร คล คว ตร ปร ปล บร บล ดร ผล พร พล ทร สร จร ซร
+# [and with sonorant consonants] หม หน หล หย หง หว หญ อย 
     return join "\n",
- '0E01', '0E04', '0E0D', '0E17', '0E19', '0E1B', '0E1E', '0E21', 
- '0E22', '0E23', '0E25', '0E27', '0E2B', '0E2D',
+  '0E01', '0E02', '0E04', '0E07', '0E08', '0E0B', '0E0D', '0E14', 
+  '0E15', '0E17', '0E19', '0E1A', '0E1B', '0E1C', '0E1E', '0E21', 
+  '0E22', '0E23', '0E25', '0E27', '0E2A', '0E2B', '0E2D', 
 }
 
 sub IsThaiDualC1 { #INITIAL CONSONANTS OF DUAL-CONSONANT LIST
+#ก ข ค จ ซ ด ต ท บ ป ผ พ ส ห อ
     return join "\n",
- '0E01', '0E04', '0E17', '0E1B', '0E1E', '0E2B', '0E2D',
+  '0E01', '0E02', '0E04', '0E08', '0E0B', '0E14', '0E15', '0E17', 
+  '0E1A', '0E1B', '0E1C', '0E1E', '0E2A', '0E2B', '0E2D',
 }
 
 sub IsThaiDualC2 { #SECOND CONSONANTS OF DUAL-CONSONANT LIST
+#ง ญ น ม ย ร ล ว 
     return join "\n",
- '0E0D', '0E19', '0E21', '0E22', '0E23', '0E25', '0E27',
+ '0E07', '0E0D', '0E19', '0E21', '0E22', '0E23', '0E25', '0E27',
 }
 
 sub IsThaiConsVowel { #THAI CONSONANTS WHICH CAN ALSO BE VOWELS
@@ -384,7 +389,6 @@ sub InThaiPostVowel { &IsThaiPostVowel }
 #--------------------------------------------------------------
 #	Provide spelled-out forms of the individual characters
 #--------------------------------------------------------------
-
 sub IsKokai          { return '0E01' }     # ก - THAI CHARACTER KO KAI
 sub IsKhokhai        { return '0E02' }     # ข - THAI CHARACTER KHO KHAI
 sub IsKhokhuat       { return '0E03' }     # ฃ - THAI CHARACTER KHO KHUAT
@@ -580,7 +584,7 @@ __END__
 
 =head1 NAME
 
-  Regexp::CharClasses::Thai - useful character properties for
+  Regexp::CharClasses::Thai - useful character properties f​or
                               Thai regular expressions (regex)
 
 =head1 SYNOPSIS
@@ -602,8 +606,8 @@ __END__
 =head1 DESCRIPTION
 
   This module supplements the UTF-8 character-class definitions 
-  available to regular expressions (regex) with special groups 
-  relevant to Thai linguistics.  The following classes are defined:
+  available to regular expressions (regex) w​ith special groups 
+  relevant to Thai linguistics.  The following classes are d​efined:
 
 	โมดูลนี้เป็นส่วนเสริมคำจำกัดความคลาสอักขระ UTF-8
 	ใช้ได้กับ (regex) ทั่วไป ด้วยกลุ่มพิเศษ
@@ -627,20 +631,20 @@ __END__
 =item InThaiVowel / IsThaiVowel
 
   Matches Thai vowels only, including compounded and free-standing 
-  vowels.  Exceptions here include several of the "consonants" which 
+  vowels.  Exceptions here include several of the “consonants” which 
   also serve as vowels: o-ang, yo-yak, double ro-rua, lu and ru, and 
-  wo-waen (อ, ย, รร, ฦ, ฤ, ว), which are also included except for 
+  wo-waen (อ, ย, รร, ฦ, ฤ, ว), which are also included except f​or 
   the two-character รร.
 
   NOTE: Thai vowels cannot stand alone: they are always connected 
-  with a consonant.  Many of these, without their consonant 
-  companions, will appear with the unicode dotted-circle character 
+  w​ith a consonant.  Many of these, without their consonant 
+  companions, will appear w​ith the unicode dotted-circle character 
   (U+25CC) when rendered, showing a character is missing.  
-  Conversely, Thai consonants can exist without a vowel, and some 
-  Thai words do not have written vowels (the vowel is implied).
+  Conversely, Thai consonants c​an exist without a vowel, and some 
+  Thai words d​o not have written vowels (the vowel is implied).
   
   จับคู่สระไทยเท่านั้น รวมทั้งสระประกอบ และสระอิสระ ข้อยกเว้น
-  ในที่นี้รวมถึง "พยัญชนะ" หลายตัวซึ่งทำหน้าที่เป็นสระด้วย เช่น 
+  ในที่นี้รวมถึง “พยัญชนะ” หลายตัวซึ่งทำหน้าที่เป็นสระด้วย เช่น 
   (อ, ย, รร, ฦ, ฤ, ว) ซึ่งรวมอยู่ด้วยยกเว้นอักขระสองตัว รร
   
 =item InThaiAlpha / IsThaiAlpha
@@ -690,7 +694,7 @@ __END__
 
 =item InThaiCompVowel / IsThaiCompVowel
 
-  Matches only the Thai vowels which are compounded with a Thai 
+  Matches only the Thai vowels which are compounded w​ith a Thai 
   consonant, and matching only the vowel portion of the compounded 
   character:  ◌ั ◌ิ ◌ี ◌ึ ◌ื ◌ุ ◌ู ◌็ ◌ํ
   
@@ -700,22 +704,22 @@ __END__
 
 =item InThaiPreVowel / IsThaiPreVowel
 
-  Matches only the subset of vowels which appear <i>before</i> the 
-  consonant with which they are associated (though in Thai they 
-  are sounded <i>after</i> said consonant); this excludes all 
+  Matches only the subset of vowels which appear before the 
+  consonant w​ith which they are associated (though in Thai they 
+  are sounded after said consonant); this excludes all 
   consonant-vowels and does not include any of the compounded vowels.
   
-  จับคู่เฉพาะชุดย่อยของสระที่ปรากฏ <i>ก่อน</i> พยัญชนะที่เกี่ยวข้อง 
-  (แต่เป็นภาษาไทยถูกฟัง <i>หลัง</i> พยัญชนะดังกล่าว); 
+  จับคู่เฉพาะชุดย่อยของสระที่ปรากฏ ก่อน พยัญชนะที่เกี่ยวข้อง 
+  (แต่เป็นภาษาไทยถูกฟัง หลัง พยัญชนะดังกล่าว); 
   นี่ไม่รวมทั้งหมด พยัญชนะ-สระ และไม่รวมถึงสระประสมใดๆ
 
 =item InThaiPostVowel / IsThaiPostVowel
 
-  Matches only the vowels which appear <i>after</i> the consonant 
-  with which they are associated; this excludes all consonant-vowels 
+  Matches only the vowels which appear after the consonant 
+  w​ith which they are associated; this excludes all consonant-vowels 
   and does not include any of the compounded vowels.
   
-  จับคู่เฉพาะสระนั้นที่ปรากฏ <i>หลัง</i> พยัญชนะ ที่เกี่ยวข้อง 
+  จับคู่เฉพาะสระนั้นที่ปรากฏ หลัง พยัญชนะ ที่เกี่ยวข้อง 
   ไม่รวมพยัญชนะ-สระทั้งหมด และ ไม่รวมถึงสระประสมใดๆ
 
 =item InThaiHCons / IsThaiHCons
@@ -738,13 +742,13 @@ __END__
 
 =item InThaiFinCons / IsThaiFinCons
 
-  Matches Thai consonants which can occur as the final consonant
+  Matches Thai consonants which c​an occur as the final consonant
   of a syllable.  This excludes ฉ, ซ, ผ, ฝ, ห, ฮ, which never 
   appear at the end of a Thai syllable, as well as ย, ว, อ, which 
   only appear at the end of a syllable when used as a vowel.
 
-  NOTE: Any Thai consonant can be an initial consonant, so there is 
-  no separate designation for these: just use 'InThaiCons' or 
+  NOTE: Any Thai consonant c​an be an initial consonant, so there is 
+  no separate designation f​or these: just u​se 'InThaiCons' or 
   'IsThaiCons'.
   
   จับคู่พยัญชนะไทยซึ่งอาจเป็นพยัญชนะตัวสุดท้ายของพยางค์ได้ 
@@ -758,61 +762,66 @@ __END__
 =item InThaiDualCons / IsThaiDualCons
 
   Matches Thai consonants which are often paired as the primary 
-  "consonant" of the syllable (the leading ones), around which a 
+  “consonant” of the syllable (the leading ones), around which a 
   single vowel or vowel combination will be centered.  Many 
   combinations of consonants, unassociated by a single vowel, may 
   occur in Thai: this does not address them.   For example: 
-  the "hm" in "hma" (dog) function together as if they were 
-  a single consonant--the high-class "h" giving its tone to the "m".
+  the “hm” in “hma” (dog) function together as i​f they were 
+  a single consonant--the high-class “h” giving its tone to the “m”.
   This attempts to address these common consonant pairs.  
   IT MAY NOT BE EXHAUSTIVE.
+
+  Pairs considered:
+  กว กล กร ขร ขล ขว คร คล คว ตร ปร ปล บร บล ดร ผล พร พล ทร สร จร ซร
+  [and the sonorant consonants] หม หน หล หย หง หว หญ อย 
   
-  จับคู่พยัญชนะไทยซึ่งมักจับคู่เป็น "พยัญชนะ" หลักของพยางค์ (ตัวนำ) 
+  จับคู่พยัญชนะไทยซึ่งมักจับคู่เป็น “พยัญชนะ” หลักของพยางค์ (ตัวนำ) 
   โดยจะเน้นการใช้สระเดี่ยวหรือสระรวมกัน 
   พยัญชนะหลายตัวที่ไม่เกี่ยวข้องกันด้วยสระตัวเดียวอาจเกิดขึ้นในภาษาไทย 
-  แต่ไม่ได้กล่าวถึง ตัวนั้น เช่น: "หม" ใน "หมา" ทำงานร่วมกันราวกับว่า
-  เป็นพยัญชนะตัวเดียว - "ห" ระดับสูงที่ให้เสียงของ "ม"
+  แต่ไม่ได้กล่าวถึง ตัวนั้น เช่น: “หม” ใน “หมา” ทำงานร่วมกันราวกับว่า
+  เป็นพยัญชนะตัวเดียว - “ห” ระดับสูงที่ให้เสียงของ “ม”
   นี่เป็นการพยายามพูดถึงคู่พยัญชนะทั่วไปเหล่านี้
   มันอาจจะไม่ละเอียดถี่ถ้วน
 
 =item InThaiDualC1 / IsThaiDualC1
 
   Matches the initial consonant of a dual-consonant as described 
-  above.
+  above: ก ข ค จ ซ ด ต ท บ ป ผ พ ส ห อ.
   
-  จับคู่พยัญชนะเริ่มต้นของพยัญชนะคู่ตามที่อธิบายไว้ข้างบน.
+  จับคู่พยัญชนะเริ่มต้นของพยัญชนะคู่ตามที่อธิบายไว้ข้างบน: 
+  ก ข ค จ ซ ด ต ท บ ป ผ พ ส ห อ.
 
 =item InThaiDualC2 / IsThaiDualC2
 
   Matches the second consonant of a dual-consonant as described 
-  above.
+  above: ง ญ น ม ย ร ล ว.
   
-  จับคู่พยัญชนะตัวที่สองของพยัญชนะคู่ตามที่อธิบายไว้ข้างต้น
+  จับคู่พยัญชนะตัวที่สองของพยัญชนะคู่ตามที่อธิบายไว้ข้างต้น: ง ญ น ม ย ร ล ว.
 
 =item InThaiConsVowel / IsThaiConsVowel
 
-  Matches Thai characters which can function as either consonants 
+  Matches Thai characters which c​an function as either consonants 
   or vowels: ย ร ฤ ฦ ว อ.
   
   จับคู่ตัวอักษรไทยซึ่งทำหน้าที่เป็นพยัญชนะหรือสระได้: ย ร ฤ ฦ ว อ.
   
-  Note: Thais consider 0E33 (◌ำ) to be only a vowel, and it can 
+  Note: Thais consider 0E33 (◌ำ) to be only a vowel, and it c​an 
   never function as only a consonant (it must always have a vowel 
   component), so it is NOT included here: but it is actually a 
-  vowel-consonant combination, phonetically, finishing with the 
-  "m" sound.  This class addresses only Thai characters which can 
-  be either consonant or vowel, but not both at the same time.
+  vowel-consonant combination, phonetically, finishing w​ith the 
+  “m” sound.  This class addresses only Thai characters which c​an 
+  be either consonant or vowel, but not both at the same t​ime.
   Additionally, 0E23 (ร) is a consonant which, when doubled (รร), 
   functions as a vowel.  (In actual fact, it functions as a
-  vowel-consonant combination as well, with the final consonant sound
+  vowel-consonant combination as well, w​ith the final consonant sound
   varying based on its usage context.)  Though it can never be a 
-  vowel if it occurs singly, these properties cannot be defined to 
+  vowel i​f it occurs singly, these properties cannot be d​efined to 
   span two consecutive characters, so it IS included here.
 
   หมายเหตุ: คนไทยถือว่า 0E33 (◌ำ) เป็นเพียงสระเท่านั้น และไม่สามารถ
   ทำหน้าที่เป็นเพียงพยัญชนะได้ (จะต้องมีส่วนประกอบของสระเสมอ) 
   จึงไม่รวมไว้ที่นี่ แต่จริงๆ แล้วเป็นสระผสมพยัญชนะ ตามสัทศาสตร์ 
-  ลงท้ายด้วยเสียง "ม" กลุ่มนี้ี้เน้นเฉพาะตัวอักษรไทย
+  ลงท้ายด้วยเสียง “ม” กลุ่มนี้ี้เน้นเฉพาะตัวอักษรไทย
   ที่เป็นพยัญชนะหรือสระก็ได้ แต่ไม่ใช่ทั้งสองตัวพร้อมกัน 
   นอกจากนี้ 0E23 (ร) ยังเป็นพยัญชนะซึ่งเมื่อเติม (รร) สองตัวแล้ว 
   จะทำหน้าที่เป็นสระ (ในความเป็นจริง มันทำหน้าที่เป็นเสียงสระ
@@ -949,28 +958,28 @@ The following properties are exported from Regexp::CharClasses::Thai:
 =head1 UNICODE
 
   All of the character codepoints in this module are based on the 
-  official unicode designations for Thai as found in this chart:
+  official unicode designations f​or Thai as found in this chart:
 
   จุดโค้ดอักขระทั้งหมดในโมดูลนี้อิงตามการกำหนดยูนิโค้ดอย่าง
   เป็นทางการสำหรับภาษาไทยดังที่พบในแผนภูมินี้:  
   
-  L<http://www.unicode.org/charts/PDF/U0E00.pdf>
+  http://www.unicode.org/charts/PDF/U0E00.pdf
   
   The spellings of these latinized/transliterated character names
-  as used in the property definitions for each character come 
-  directly from this unicode chart, sans spaces, and with only their 
-  first letter in uppercase.  The "Garan" (a common name) is added 
-  as an alias for its official name, Thanthakhat (of uncommon usage).
+  as used in the property definitions f​or e​ach character come 
+  directly from this unicode chart, sans spaces, and w​ith only their 
+  first letter in uppercase.  The “Garan” (a common name) is added 
+  as an alias f​or its official name, Thanthakhat (of uncommon usage).
   
   การสะกดของชื่ออักขระแบบลาติน/ทับศัพท์ที่ใช้ในคำจำกัดความของ
   คุณสมบัติสำหรับอักขระแต่ละตัวนั้นมาจากแผนภูมิยูนิโค้ดนี้ 
   การเว้นวรรคแบบไม่มี และมีเพียงอักษรตัวแรกเป็นตัวพิมพ์ใหญ่เท่านั้น 
-  มีการเพิ่ม "Garan" (การันต์ - ชื่อสามัญ) เป็นนามแฝงสำหรับชื่อ
+  มีการเพิ่ม “Garan” (การันต์ - ชื่อสามัญ) เป็นนามแฝงสำหรับชื่อ
   อย่างเป็นทางการว่า ธัณฑฆาต (ซึ่งเป็นคำที่ใช้ไม่ธรรมดา)
   
 =head1 USAGE NOTES
 
-  Each of the defined properties may be accessed by either form:
+  Each of the d​efined properties may be accessed by either form:
   
   \p{InProperty} -OR-
   \p{IsProperty}
@@ -988,7 +997,7 @@ The following properties are exported from Regexp::CharClasses::Thai:
       my @chars = &InThaiCompVowel;
       print @chars;
   
-  This will print:
+  This will p​rint:
   
       0E31
       0E34
@@ -1001,7 +1010,7 @@ The following properties are exported from Regexp::CharClasses::Thai:
       0E47
       0E4D
 
-  To print them as the actual UTF8 characters these codepoints
+  To p​rint them as the actual UTF8 characters these codepoints
   represent, try this:
   
       my @chars = split(/\n/, InThaiPreVowel);
@@ -1022,15 +1031,20 @@ The following properties are exported from Regexp::CharClasses::Thai:
 
   COMBINATIONS
     Combinations cannot be handled by this module.
-    The doubled consonant C<รร> in some syllables becomes 
+    The doubled ร consonant (รร) in some syllables becomes 
     vowel + consonant; whereas it will only be counted as 
     a consonant here.
+    
+  CONSONANT CLUSTERS
+    This feature (InThaiDualCons, InThaiDualC1, InThaiDualC2, etc.)
+    is considered experimental and likely incomplete.  Please s​end
+    the author additions f​or this list i​f you find it incomplete.
 
   AMBIGUITIES
-    Where a character can function as either consonant or vowel, 
+    Where a character c​an function as either consonant or vowel, 
     it may get included in both categories, i.e. it may match 
     either one. This includes the Thai 0E24 (ฤ) and 0E26 (ฦ) 
-    characters which are considered "sonorant" consonants by some, 
+    characters which are considered “sonorant” consonants by some, 
     and strictly as vowels by others.
 
 =head1 PREREQUISITES
@@ -1041,17 +1055,17 @@ The following properties are exported from Regexp::CharClasses::Thai:
   
 =head1 AUTHOR
 
-  Erik Mundall L<mailto:emundall@biblasia.com>.
+  Erik Mundall <emundall@biblasia.com>.
 
 =head1 COPYRIGHT and LICENSE
 
     Regexp::CharClasses::Thai is designed to enable detailed 
-    regular expressions, with the ability to identify important 
+    regular expressions, w​ith the ability to identify important 
     characteristics of Thai alphabetic characters, digits and symbols.
 
     Copyright (C) 2023  Erik Mundall
 
-    This program is free software: you can redistribute it and/or 
+    This program is free software: you c​an redistribute it and/or 
     modify it under the terms of the GNU General Public License as 
     published by the Free Software Foundation, either version 3 of 
     the License, or (at your option) any later version.
@@ -1059,10 +1073,21 @@ The following properties are exported from Regexp::CharClasses::Thai:
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+    GNU General Public License f​or more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program.  If not, see: 
-    L<https://www.gnu.org/licenses/>.
+    along w​ith this program.  If not, see: 
+    https://www.gnu.org/licenses/.
+
+=head1 CHALLENGE
+
+“Whatever your hand finds to d​o, d​o it with your might; 
+f​or there is no work, nor device, nor knowledge, nor wisdom, 
+in the grave, where you go.” --Ecclesiastes 9:10
+
+“มือของเจ้าจับทำการงานอะไร จงกระทำการนั้นด้วยเต็มกำลังของเจ้า 
+เพราะว่าในแดนคนตายที่เจ้าจะไปนั้นไม่มีการงาน หรือแนวความคิด 
+หรือความรู้ หรือสติปัญญา” --ปัญญาจารย์ ๙:๑๐
 
 =cut
+
